#include "lib/shared.fx"
#include "lib/structs.fx"

static const float3 vLightDir = -normalize( float3(0.4, -1.0, 0.2) );


texture		tBase;
sampler2D	smpBase = sampler_state {
	Texture = (tBase);
	MagFilter = Linear; MinFilter = Linear; MipFilter = Linear;
};

texture		tShadow;
sampler2D	smpShadow = sampler_state {
	Texture = (tShadow);
	MinFilter = Linear; MagFilter = Linear; MipFilter = Linear;
	AddressU = Clamp; AddressV = Clamp;
};


struct SOutput11 {
	float4 pos : POSITION;
	float2 uv  : TEXCOORD0;
	float4 uvs : TEXCOORD1;
	float4 color : COLOR0;
};


SOutput11 vsMain( SPosNTex i ) {
	SOutput11 o;
	o.pos = mul( i.pos, mViewProj );
	float diff = max( 0, dot( i.normal, vLightDir ) ) * 0.6;
	o.color = diff + 0.5;
	o.uv = i.uv;
	float4 vpos = mul( i.pos, mView );
	o.uvs = mul( vpos, mShadowProj );
	return o;
}


technique tecFFP
{
	pass P0 {
		VertexShader = compile vs_1_1 vsMain();
		PixelShader = NULL;
		
		Sampler[0] = (smpBase);
		Sampler[1] = (smpShadow);

		ColorOp[0] = Modulate;
		ColorArg1[0] = Texture;
		ColorArg2[0] = Diffuse;
		AlphaOp[0] = Modulate;
		AlphaArg1[0] = Texture;
		AlphaArg2[0] = Diffuse;

		TextureTransformFlags[1] = Projected;
		ColorOp[1] = Modulate;
		ColorArg1[1] = Texture;
		ColorArg2[1] = Current;
		AlphaOp[1] = Modulate;
		AlphaArg1[1] = Texture;
		AlphaArg2[1] = Current;

		ColorOp[2] = Disable;
		AlphaOp[2] = Disable;
	}
	pass PLast {
		Texture[0] = NULL;
		Texture[1] = NULL;
		TextureTransformFlags[1] = Disable;
	}
}
